@@ -8,6 +8,15 @@ from .resolve_arg_to_type import resolve_arg_to_schema
 
 
 class SchemaDict(SchemaObject):
+    """
+    A schema specifying an object with dynamic properties (corresponding to a Python dict)
+
+    :param items: The permitted data type or schema for the properties of this object. Must
+                  be one of:
+                  A primitive Python type (str, int, bool, float)
+                  A subclass of `UserObject`
+                  An instance of `Schema`
+    """
 
     def __init__(
             self,
@@ -25,5 +34,5 @@ class SchemaDict(SchemaObject):
         return DOMDict(
             value,
             dom_info,
-            _item_type=self.additional_properties
+            item_type=self.additional_properties
         )
